aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJisi Liu <liujisi@google.com>2016-07-26 16:53:39 -0700
committerGitHub <noreply@github.com>2016-07-26 16:53:39 -0700
commit9c8f603b70de4829c1e40466a7cc8c5ea6bd0522 (patch)
treea215fca24b11165070e08e97e31fede360ae6745
parent9c8c7ea67503b207d348a1db1cd6f86e9e4e1c5f (diff)
parent6ebb1b219caca8056761e48119fe5a69e5c50094 (diff)
downloadprotobuf-9c8f603b70de4829c1e40466a7cc8c5ea6bd0522.tar.gz
protobuf-9c8f603b70de4829c1e40466a7cc8c5ea6bd0522.tar.bz2
protobuf-9c8f603b70de4829c1e40466a7cc8c5ea6bd0522.zip
Merge pull request #1854 from pherl/javalite
Cherry pick protoc-artifacts change into the javalite branch
-rwxr-xr-xprotoc-artifacts/build-protoc.sh29
-rw-r--r--protoc-artifacts/pom.xml1
2 files changed, 22 insertions, 8 deletions
diff --git a/protoc-artifacts/pom.xml b/protoc-artifacts/pom.xml
index 50866041..6bb71b6e 100644
--- a/protoc-artifacts/pom.xml
+++ b/protoc-artifacts/pom.xml
@@ -59,6 +59,7 @@
<argument>build-protoc.sh</argument>
<argument>${os.detected.name}</argument>
<argument>${os.detected.arch}</argument>
+ <argument>protoc</argument>
</arguments>
</configuration>
</plugin>
diff --git a/protoc-artifacts/build-protoc.sh b/protoc-artifacts/build-protoc.sh
index 88e6ae50..328d6731 100755
--- a/protoc-artifacts/build-protoc.sh
+++ b/protoc-artifacts/build-protoc.sh
@@ -1,17 +1,30 @@
#!/bin/bash
# Builds protoc executable into target/protoc.exe
# To be run from Maven.
-# Usage: build-protoc.sh <OS> <ARCH>
+# Usage: build-protoc.sh <OS> <ARCH> <TARGET>
# <OS> and <ARCH> are ${os.detected.name} and ${os.detected.arch} from os-maven-plugin
+# <TARGET> can be "protoc" or "protoc-gen-javalite"
OS=$1
ARCH=$2
+MAKE_TARGET=$3
-if [[ $# < 2 ]]; then
+if [[ $# < 3 ]]; then
echo "No arguments provided. This script is intended to be run from Maven."
exit 1
fi
+case $MAKE_TARGET in
+ protoc-gen-javalite)
+ ;;
+ protoc)
+ ;;
+ *)
+ echo "Target ""$TARGET"" invalid."
+ exit 1
+esac
+
# Under Cygwin, bash doesn't have these in PATH when called from Maven which
# runs in Windows version of Java.
export PATH="/bin:/usr/bin:$PATH"
@@ -126,7 +139,7 @@ checkDependencies ()
}
############################################################################
-echo "Building protoc, OS=$OS ARCH=$ARCH"
+echo "Building protoc, OS=$OS ARCH=$ARCH TARGET=$TARGET"
# Nested double quotes are unintuitive, but it works.
cd "$(dirname "$0")"
@@ -134,7 +147,6 @@ cd "$(dirname "$0")"
WORKING_DIR=$(pwd)
CONFIGURE_ARGS="--disable-shared"
-MAKE_TARGET="protoc"
if [[ "$OS" == windows ]]; then
MAKE_TARGET="${MAKE_TARGET}.exe"
fi
@@ -209,12 +221,13 @@ fi
export CXXFLAGS LDFLAGS
-TARGET_FILE=target/protoc.exe
+TARGET_FILE=target/$MAKE_TARGET.exe
cd "$WORKING_DIR"/.. && ./configure $CONFIGURE_ARGS &&
- cd src && make clean && make $MAKE_TARGET &&
+ cd src && make clean && make $MAKE_TARGET -j4 &&
cd "$WORKING_DIR" && mkdir -p target &&
- (cp ../src/protoc $TARGET_FILE || cp ../src/protoc.exe $TARGET_FILE) ||
+ (cp ../src/$MAKE_TARGET $TARGET_FILE ||
+ cp ../src/$MAKE_TARGET.exe $TARGET_FILE) ||
exit 1
if [[ "$OS" == osx ]]; then
@@ -1,17 +1,30 @@
#!/bin/bash
-# Builds protoc executable into target/protoc.exe
+# Builds protoc executable into target/protoc.exe; optionally build protoc
+# plugins into target/protoc-gen-*.exe
# To be run from Maven.